<?php
namespace Planejamento\Entities;

use Geral\Entities\Base\Servico;
use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use Geral\Util\TratamentoDeMensagens;
use Setforms2\Shared\Registry;

class Custpadr extends Base\Custpadr
{

    /**
     * Busca um registro de acordo com os valores passados por parâmetro.
     * Retorna o registro, ou false se ele não for encontrado.
     *
     * @param $nrorg
     * @param $cdfilial
     * @param $cdservfili
     * @param $dtrefcuspadr
     *
     * @return bool.
     */
    public static function verificaExistenciaRegistro(
        $nrorg, $cdfilial, $cdservfili, $dtrefcuspadr
    ) {
        $registro = Custpadr::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ? AND DTREFCUSPADR = ?',
            array($nrorg, $cdfilial, $cdservfili, $dtrefcuspadr)
        );
        if (empty($registro) === false) {
            return $registro;
        }
        return false;
    }

    public static function customSave(
        $nrorg, $cdfilial, $cdservfili, $dtrefcuspadr,
        $vrcustpadr,
        $dtinclusao, $dtultatu, $nrorginclusao, $nrorgultatu,
        $cdoperinclusao, $cdoperultatu
    ) {
        $connection = Registry::getEntityManager();
        try{
            $connection->beginTransaction();
            //
            $custpadr = new Custpadr;
            //
            $custpadr->setNrorg($nrorg);
            $custpadr->setCdfilial($cdfilial);
            $custpadr->setCdservfili($cdservfili);
            $custpadr->setDtrefcuspadr($dtrefcuspadr);
            //
            $custpadr->setVrcustpadr($vrcustpadr);
            //
            $custpadr->setNrorginclusao($nrorginclusao);
            $custpadr->setNrorgultatu($nrorgultatu);
            $custpadr->setDtinclusao($dtinclusao);
            $custpadr->setDtultatu($dtultatu);
            $custpadr->setCdoperinclusao($cdoperinclusao);
            $custpadr->setCdoperultatu($cdoperultatu);
            //
            $custpadr->persist();
            //
            $connection->flush();
            $connection->commit();
            //
            tk_message(tk_get_message_by_name('msg_ger04100_inserido'), 'success');
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public static function customUpdate(
        $nrorg, $cdfilial, $cdservfili, $dtrefcuspadr,
        $vrcustpadr,
        $dtultatu, $nrorgultatu, $cdoperultatu
    ) {
        $connection = Registry::getEntityManager();
        try {
            $connection->beginTransaction();
            //
            $custpadr = Custpadr::getObjectByWhere(
                "NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ? AND DTREFCUSPADR = ?",
                array($nrorg, $cdfilial, $cdservfili, $dtrefcuspadr)
            );
            //
            $custpadr->setVrcustpadr($vrcustpadr);
            //
            $custpadr->setNrorgultatu($nrorgultatu);
            $custpadr->setDtultatu($dtultatu);
            $custpadr->setCdoperultatu($cdoperultatu);
            //
            $custpadr->persist();
            //
            $connection->flush();
            $connection->commit();
            //
            tk_message(tk_get_message_by_name('msg_ger04100_atualizado'), 'success');
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public static function customDelete($custpadr) {
        $connection = Registry::getEntityManager();
        try {
            $connection->beginTransaction();
            //
            $custpadr->delete();
            //
            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public static function clonaCustpadr(Servico $servicoModelo, Servico $servicoNovo, $conn){

            $codigomodelo = $servicoModelo->getCdservfili();
            $codigonovo = $servicoNovo->getCdservfili();
            $codigofilial = $servicoNovo->getCdfilial();
            $nrorg = Ambiente::getNrorg();
            $registrosCustpadr = Custpadr::getObjectsByWhere('
                NRORG = ? AND CDSERVFILI = ? AND CDFILIAL = ?',
                array($nrorg,$codigomodelo, $codigofilial ) );


            $operador = Ambiente::getCdOperador();
            $dtAtual = DateUtil::getDataAtual();
            if($registrosCustpadr != false){
                /** @var $registronovo Custpadr */
                foreach($registrosCustpadr as $registromodelo){
                    $registronovo = clone $registromodelo;
                    $registronovo->setCdservfili($codigonovo);
                    $registronovo->setDtultatu($dtAtual);
                    $registronovo->setDtinclusao($dtAtual);
                    $registronovo->setCdoperinclusao($operador);
                    $registronovo->setCdoperultatu($operador);

                    $registronovo->persist();
                    $conn->flush();
                }
            }

    }

}